pub struct AttemptOptimisticPrefixMatch {
pub matched_bytes: usize,
pub any_implicit_bytes: bool,
}Expand description
This struct represents a successful match against a prefix using the
InnerNodeCommon::attempt_pessimistic_match_prefix function.
Fields
matched_bytes: usizeHow many bytes were matched
any_implicit_bytes: boolThis flag will be true if the attempt_pessimistic_match_prefix
function fell back to an optimistic mode, and assumed prefix match by
key length.